@@ -8,8 +8,8 @@ nest.py -- a python interface to the Nest Thermostats
 from __future__ import print_function
 
 import argparse
-# TODO(jkoelker) six?
-import ConfigParser as configparser
+# use six for python2/python3 compatibility
+from six.moves import configparser
 import os
 import sys
 
